function [v]=average_speeds(G,Q,Area)
% average_speeds: computes the average speeds for a capillary bed
% Calling instruction: [v]=average_speeds(G,Q,Area) 
% Input:  G = matrix of the graph  (lengths of edges in mm)
%         Q = matrix of volumetric flow rates (in mm^3/s)
%         Area = area of the capillary cross-section (in mm^2)
% Output: v = matrix of average speeds (in mm/s)

n=length(G);  % determines the number of nodes
v=zeros(n); % initialises the matrix of speeds
for i=1:n
 for j=1:n
  if G(i,j)~=0
% if nodes i and j are connected, compute the average speed 
% in capillary C_ij
   v(i,j)=Q(i,j)/Area;
% print the average speeds (recall C_ij=C_ji, so it suffices to
% print the values for j>i)          
   if j>i
    fprintf('The average speed at C_%1d%1d is %8.4f mm/s\n',...
       i,j,v(i,j))
   end
  end
 end
end

