function [un_final]=dolphins3(Nh)
% dolphins3: solves problem "Aeolian dolphins (3)"
% Calling instruction: un_final=dolphins3(Nh)
% Input: Nh = number of time steps
% Output: un_final = solution at the final time

% define the data of the problem
t0=2017.5; tf=2025.5; % endpoints of the time interval
y0=100;               % initial condition
b=@(t)-0.03*(2-exp(-5*(sin(t*pi)).^2)); % function b(t)
f=@(t,y)0.06*(1-y/150)*y+b(t)*y;       % function f(t,y)
% compute the numerical solution by the Euler method
[tn,un]=euler(f,t0,tf,y0,Nh); 
un_final=un(end); % saves the numerical solution at time tf 
% plot the numerical solution over the entire time interval
figure(1);
plot(tn,un,'.','Markersize',16); grid on
xlabel('t'); ylabel('y(t)')
