function [tn,un]=euler(f,t0,tf,y0,Nh)
% euler: Euler method for the Cauchy problem
% Calling instruction: [tn,un]=euler(f,t0,tf,y0,Nh) 
% Approximation of the solution of Cauchy problem:
%                  y'(t)=f(t,y(t))   for t in [t0,tf]
%                  y(t0)=y0
% Input: f = function handle for the function f(t,y)
%        t0,tf = endpoints of time interval
%        y0 = datum of initial condition
%        Nh = number of points of discretisation (excluding t0)
% Output: tn = column vector of discretisation points 
%              (including t0)
%         un = column vector of numerical solution 
%              (including u0=y0)
tn=linspace(t0,tf,Nh+1)'; % discretisation points
h=(tf-t0)/Nh;             % discretisation step
un=zeros(Nh+1,1); % initialises the vector of the numerical 
%                   solution
un(1)=y0; % stores the initial condition in the first 
%           component of vector one
for n=1:Nh % computes the numerical solution by the Euler method
    un(n+1)=un(n)+h*f(tn(n),un(n)); 
end
