function [Q]=flow_rates(G,p,R)
% flow_rates: computes the volumetric flow rates in a capillary bed
% Calling instruction: [Q]=flow_rates(G,p,R) 
% Input:  G = matrix of the graph (lengths of edges in mm)
%   p = vector of pressures at the nodes of the bed (in mmHg)
%   R = resistance in capillaries (in g/(mm^5 s) )
% Output: Q = volumetric-flow-rate matrix (in mm^3/s)

n=length(p); % determines the number of nodes
Q=zeros(n);  % initialises the volumetric-flow-rate matrix
% compute volumetric flow rates and print
for i=1:n  % loop over nodes
  for j=1:n  % loop over nodes 
    if G(i,j)~=0 
% if nodes i and j are connected, compute the volumetric 
% flow rate Q_ij 
      Q(i,j)=133.32*abs(p(i)-p(j))/(R*G(i,j));
% print the volumetric flow rates (recall C_ij=C_ji,
% so it suffices to print the values for j>i) 
      if j>i         
        fprintf('The flow rate C_%1d%1d is %8.3e mm^3/s\n',...
              i,j,Q(i,j))
      end
    end
  end
end
