function [x]=gem(A,b)
% gem: computes the solution to system Ax=b using GEM
% Calling instruction: x=gem(A,b)
% Input: A = square matrix of the system
%        b = column vector, right-hand-side term of the system
% Output: x = column vector, solution of the system
[n,m]= size(A); % computes the size of A
[nrb,ncb]=size(b); % computes the dimension of  b
if n == m && n==nrb
% the system is solved only if the matrix A is square and 
% b is a column vector of the same dimension as A
% reduction step
  for k=1:n-1
     for i=k+1:n
        if A(k,k)==0
           warning('GEM cannot terminate');
           x=[ ]; return
        end
        mik=A(i,k)/A(k,k);
        for j=k+1:n
           A(i,j)=A(i,j)-mik*A(k,j);
        end
        b(i)=b(i)-mik*b(k);
     end
  end
% back-substitution step
  x=zeros(n,1);
  x(n)=b(n)/A(n,n);
  for i=n-1:-1:1
     s=0;
     for j=i+1:n
        s=s+A(i,j)*x(j);
     end
     x(i)=(b(i)-s)/A(i,i);
  end
else %  the system cannot be solved by GEM
disp('The matrix is not square')
x=[ ];
end
