function hakes_sharks(Nh)
% hakes_sharks: solves problem "Hakes and Sharks"
% Calling function: hakes_sharks(Nh)
% Input: Nh = number of time steps
% Output: graphic window

t0=0; tf=80; % endpoints of time interval
p0=5000; s0=40; % initial conditions
rp=.6; rs=-.2; Kp=3.e5; sigmap=rp/Kp; % data
sigmas=1.e-4; alpha=0.001; mu=.01;
f1=@(t,p,s)(rp-sigmap*p-alpha*s)*p; 
f2=@(t,p,s)(rs-sigmas*s+mu*alpha*p)*s;
% compute the numerical solution by the Euler method
[tn,un,vn]=euler2(f1,f2,t0,tf,p0,s0,Nh);
fprintf('%6.0f hakes and %6.0f sharks at time t=%d \n',...
    un(end),vn(end),tf) % prints on screen
% plot the numerical solution 
% the command plotyy uses two different scales on the same graph 
figure(1); clf; 
[ax,h1,h2]=plotyy(tn,un,tn,vn); grid on
set(h1,'Linewidth',2);
set(h2,'Linewidth',2);
% plot the phase-plane
figure(2); clf; 
plot(un(1),vn(1),'r*',un,vn,'Linewidth',2); 
grid on

