function hakes_sharks_fishing_bis(Nh)
% hakes_sharks_fishing_bis: solves problem "Hakes and Sharks 
%  with harvest"
% Calling instruction: hakes_sharks_fishing_bis(Nh)
% Input: Nh = number of time steps
% Output: graphic window

% define the problem data
t0=0; tf=80; % endpoints of the time interval
p0=5000; s0=40; % initial conditions
rp=.6; rs=-.2; Kp=3.e5; sigmap=rp/Kp; % data
sigmas=1.e-4; alpha=0.001; mu=.01;
figure(1); clf; figure(2); clf; % opens and wipes figures
for bd=[0.4,0.5,0.6] % loop over the three different values of bd
f1=@(t,p,s)(rp-sigmap*p-alpha*s-bd)*p;
f2=@(t,p,s)(rs-sigmas*s+mu*alpha*p-bd)*s;
% compute the numerical solution by the Euler method
[tn,un,vn]=euler2(f1,f2,t0,tf,p0,s0,Nh);
% plot the numerical solution
figure(1); 
plot(tn,un,'Linewidth',2); 
hold on; grid on
figure(2); 
plot(tn,vn,'Linewidth',2); 
hold on; grid on
end
figure(1); 
xlabel('t'); ylabel('preys (hakes)');
legend('bd=0.4','bd=0.5','bd=0.6')
figure(2); 
xlabel('t'); ylabel('predators (sharks)');
legend('bd=0.4','bd=0.5','bd=0.6')
