function plot_7bed(G,p,v)
% plot_7bed: plots the pressures and the average velocities
%            in capillaries of the 7-capillary bed
% Calling instruction: plot_7bed(G,p,v)
% Input: G = graph matrix with capillary lengths
%        p = vector of pressures at the nodes of the bed
%        v = matrix of average speeds (in mm/s)
% Output: graphic window
n=length(G);
m=sqrt(n-2);

% define the nodes of the bed
sa=3/5;ca=4/5;
xy=[0,0; % node 0
    0.3, 0; % node 1
    0.3+0.3*ca, 0.3*sa; % node 2 
    0.3+0.4*sa, -0.4*ca; % node 3
    0.3+2*0.3*ca, 0; % node 4;
    0.3+2*0.3*ca+0.3,0]; % node 5

x=xy(1:n,1); y=xy(1:n,2);
x=x+abs(min(x)); y=y+abs(min(y));
xy=[x,y];    

%
np=32;
colore=zeros(np,3);
v2=linspace(0,1,np);
colore(1:np,1)=v2; 
v1=linspace(1,0,np);
colore(:,3)=1;
colore(1:np,3)=v1;


% plot the pressures
figure(1); clf
for i=1:n
for j=i+1:n
    if G(i,j)~=0
x1=[x(i),(x(i)+x(j))/2,x(j)];
y1=[y(i),(y(i)+y(j))/2,y(j)];
p1=[p(i),(p(i)+p(j))/2,p(j)];
patch([x1 nan],[y1 nan] ,[p1,nan], [p1,nan],...
   'EdgeColor','interp','FaceColor','none','Linewidth',2);
hold on
    end
end
end
grid on
 
colormap(colore)
view([38,16])
axis([min(x),max(x),min(y),max(y),min(p),max(p)]) 
daspect([xy(end,1),xy(end,1),40]) 
t1=text(1.138,0.189,min(p)-1.5,'venule','Fontsize',16);
t2=text(-0.18, 0.35,max(p)+2,'arteriole','Fontsize',16);
zlabel('pressure (mmHg)','Fontsize',16)
colorbar
set(gca,'Fontsize',16)


% plot the velocities
figure(2); clf

cmap=colormap(hsv(32));
vmin=100;
for i=1:n
    for j=1:n
        if v(i,j)>0
vmin=min([vmin,v(i,j)]); 
        end
    end
end
vcolore=zeros(size(v));
vmax=max(max(v))*1.05;
for i=1:n
    for j=1:n
        if v(i,j)>0
vcolore(i,j)=round(1+(size(cmap,1)-1)*(v (i,j)- vmin)/(vmax-vmin));
        end
    end
end

% 
i=1;
for j=i+1:n
        if G(i,j)~=0
patch([x(i),x(j),x(j),x(i)],[y(i),y(j),y(j),y(i)] ,...
      [v(i,j),v(i,j),0,0], cmap(vcolore(i,j),:)); 
hold on
        end
end

for i1=1:m
    for i2=1:m
    i=(i2-1)*m+i1+1;
        for j=i+1:n
        if G(i,j)~=0
 patch([x(i),x(j),x(j),x(i)],[y(i),y(j),y(j),y(i)] ,...
      [v(i,j),v(i,j),0,0], cmap(vcolore(i,j),:)); 
       end
        end
    end
end
colormap(hsv(32))
colorbar
view([25,44])
daspect([xy(end,1),xy(end,1),2]) 
grid on
zlabel('average vel. (mm/s)','Fontsize',16)
t1=text(1.065 ,0.2416,v(1,2)+0.1,'venule','Fontsize',16);
t2=text(-0.08, 0.3, v(end-1,end)+0.1,'arteriole','Fontsize',16);
set(gca,'Fontsize',16)

axis([min(x),max(x),min(y),max(y),0,max(max(v))]) 
caxis([vmin,vmax])
