function plot_grid_like_bed(G,p,v)
% plot_grid_like_bed: plots the pressures and the 
%                     average velocities
% Calling instruction: plot_grid_like_bed(G,p,v)
% in capillaries of the grid-like capillary bed
% Input: G = graph matrix with capillary lengths
%        p = vector of pressures at the nodes of the bed
%        v = matrix of average speeds (in mm/s)
n=length(G);
m=sqrt(n-2);
L=G(1,2);
% define the nodes of the bed
x=zeros(n,1); y=x;
x(1)=-L/sqrt(2); y(1)=L/sqrt(2);
for i1=1:m
    for i2=1:m
        i=(i2-1)*m+i1+1;
    x(i)=L*(i1-1);
    y(i)=-L*(i2-1);
    end
end

x(n)=x(n-1)+L/sqrt(2);
y(n)=y(n-1)-L/sqrt(2);
x=x+abs(min(x)); y=y+abs(min(y));
x=x/max(abs(x)); y=y/max(abs(y));
xy=[x,y];    

np=32;
colore=zeros(np,3);
v2=linspace(0,1,np);
colore(1:np,1)=v2; 
v1=linspace(1,0,np);
colore(:,3)=1;
colore(1:np,3)=v1;


% plot the pressures
figure(1); clf
for i=1:n
for j=i+1:n
    if G(i,j)~=0
x1=[x(i),(x(i)+x(j))/2,x(j)];
y1=[y(i),(y(i)+y(j))/2,y(j)];
p1=[p(i),(p(i)+p(j))/2,p(j)];
patch([x1 nan],[y1 nan] ,[p1,nan], [p1,nan],...
   'EdgeColor','interp','FaceColor','none','Linewidth',2);
hold on
    end
end
end
grid on
 
colormap(colore)
view([-51,16])
axis([min(x),max(x),min(y),max(y),min(p),max(p)]) 
daspect([xy(end,1),xy(end,1),40]) 
t1=text(0.95,0.036,min(p)-7,'venule','Fontsize',16);
t2=text(-0.21, 0.88, max(p)+7,'arteriole','Fontsize',16);
zlabel('pressure (mmHg)','Fontsize',16)
colorbar
set(gca,'Fontsize',16)

% plot the velocities
figure(2); clf

cmap=colormap(hsv(32));
vmin=100;
for i=1:n
    for j=1:n
        if v(i,j)>0
vmin=min([vmin,v(i,j)]); 
        end
    end
end
vcolore=zeros(size(v));
vmax=max(max(v))*1.05;
for i=1:n
    for j=1:n
        if v(i,j)>0
vcolore(i,j)=round(1+(size(cmap,1)-1)*(v (i,j)- vmin)/(vmax-vmin));
        end
    end
end

% 
i=1;
for j=i+1:n
        if G(i,j)~=0
patch([x(i),x(j),x(j),x(i)],[y(i),y(j),y(j),y(i)] ,...
      [v(i,j),v(i,j),0,0], cmap(vcolore(i,j),:)); 
hold on
        end
end

for i1=1:m
    for i2=1:m
    i=(i2-1)*m+i1+1;
        for j=i+1:n
        if G(i,j)~=0
 patch([x(i),x(j),x(j),x(i)],[y(i),y(j),y(j),y(i)] ,...
      [v(i,j),v(i,j),0,0], cmap(vcolore(i,j),:)); 
       end
        end
    end
end
colormap(hsv(32))
colorbar
view([-46,26])
daspect([xy(end,1),xy(end,1),2]) 
grid on
zlabel('average vel. (mm/s)','Fontsize',16)
t1=text(0.88,0.08,v(1,2)+0.2,'venule','Fontsize',16);
t2=text(0,1,v(end-1,end)+0.2,'arteriole','Fontsize',16);
set(gca,'Fontsize',16)

axis([min(x),max(x),min(y),max(y),0,1]) 
caxis([vmin,vmax])
